<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>InfoPositionPol</name>
    <message>
        <location filename="../InfoPositionPolInit.js" line="+2"/>
        <source>&amp;Polar Position</source>
        <translation>Położenie &amp;biegunowe</translation>
    </message>
</context>
</TS>
